(function(angular, undefined){
  "use strict";
  angular
    .module("ngDjangoDisguise", [])
    .directive("disguise", {
      restrict: "A",
      scope: true,
      function($scope, element, attrs, ctrl) {
      }
    })
})(angular)
